import "./tasks/fastqc.wdl" as fastqc
import "./tasks/trimmomatic.wdl" as trimmomatic
import "./tasks/tophat2.wdl" as tophat2
import "./tasks/cufflinks.wdl" as cufflinks

workflow {{ project_name }} {
	File read1
	File read2
	File adapter
	String baseout
	File gtf
	File genome_directory
	String idx_prefix
	
	scatter ( read in [read1, read2]) {
		call fastqc.qc as fastqc {input: read=read}
	}
	
	call trimmomatic.trimmomatic as trimmomatic {
		input: baseout=baseout, read1=read1, read2=read2, adapter=adapter
	}

	call tophat2.tophat2 as tophat2 {
		input: baseout=baseout, read_1P=trimmomatic.read_1p, read_2P=trimmomatic.read_2p, gtf=gtf, genome_directory=genome_directory, idx_prefix=idx_prefix
	}

	call cufflinks.cufflinks as cufflinks {
		input: gtf = gtf, bam = tophat2.accepted_hits, genome_directory=genome_directory, idx_prefix=idx_prefix, baseout=baseout
	}
}


